@@ -19,40 +19,16 @@
 
 VOID
 InitializeLibPlatform (
-    IN EFI_HANDLE           ImageHandle __attribute__((__unused__)),
-    IN EFI_SYSTEM_TABLE     *SystemTable __attribute__((__unused__))
+    IN EFI_HANDLE           ImageHandle EFI_UNUSED,
+    IN EFI_SYSTEM_TABLE     *SystemTable EFI_UNUSED
     )
 {
 }
 
-/*
- * Calls to these functions may be emitted implicitly by GCC even when
- * -ffreestanding is in effect.
- */
-void *memset(void *s, int c, __SIZE_TYPE__ n)
-{
-    unsigned char *p = s;
-
-    while (n--)
-        *p++ = c;
-
-    return s;
-}
-
-void *memcpy(void *dest, const void *src, __SIZE_TYPE__ n)
-{
-    unsigned char *p = dest;
-    unsigned char const *q = src;
-
-    while (n--)
-        *p++ = *q++;
-
-    return dest;
-}
-
+#ifdef __GNUC__
 void __div0(void)
 {
-	// TODO handle divide by zero fault
-	while (1);
+    // TODO handle divide by zero fault
+    while (1);
 }
-
+#endif
