@@ -659,7 +659,8 @@ _DevPath1394 (
     F1394_DEVICE_PATH       *F1394;
 
     F1394 = DevPath;
-    CatPrint(Str, L"1394(%g)", &F1394->Guid);
+    // Guid has format of IEEE-EUI64
+    CatPrint(Str, L"I1394(%016lx)", F1394->Guid);
 }
 
 
@@ -863,9 +864,9 @@ _DevPathInfiniBand (
     INFINIBAND_DEVICE_PATH  *InfiniBand;
 
     InfiniBand = DevPath;
-    CatPrint( Str , L"Infiniband(0x%x,%g,0x%lx,0x%lx,0x%lx)" ,
-        InfiniBand-> ResourceFlags , InfiniBand-> PortGid , InfiniBand-> ServiceId ,
-        InfiniBand-> TargetPortId , InfiniBand-> DeviceId ) ;
+    CatPrint(Str, L"Infiniband(0x%x,%g,0x%lx,0x%lx,0x%lx)",
+        InfiniBand->ResourceFlags, InfiniBand->PortGid, InfiniBand->ServiceId,
+        InfiniBand->TargetPortId, InfiniBand->DeviceId);
 }
 
 static VOID
@@ -889,17 +890,19 @@ _DevPathUart (
     }
 
     if (Uart->BaudRate == 0) {
-        CatPrint(Str, L"Uart(DEFAULT %c",Uart->BaudRate,Parity);
+        CatPrint(Str, L"Uart(DEFAULT,");
     } else {
-        CatPrint(Str, L"Uart(%d %c",Uart->BaudRate,Parity);
+        CatPrint(Str, L"Uart(%ld,", Uart->BaudRate);
     }
 
     if (Uart->DataBits == 0) {
-        CatPrint(Str, L"D");
+        CatPrint(Str, L"DEFAULT,");
     } else {
-        CatPrint(Str, L"%d",Uart->DataBits);
+        CatPrint(Str, L"%d,", Uart->DataBits);
     }
 
+    CatPrint(Str, L"%c,", Parity);
+
     switch (Uart->StopBits) {
         case 0  : CatPrint(Str, L"D)");   break;
         case 1  : CatPrint(Str, L"1)");   break;
@@ -933,21 +936,20 @@ _DevPathHardDrive (
     Hd = DevPath;
     switch (Hd->SignatureType) {
         case SIGNATURE_TYPE_MBR:
-            CatPrint(Str, L"HD(Part%d,Sig%08X)",
+            CatPrint(Str, L"HD(%d,MBR,0x%08x)",
                 Hd->PartitionNumber,
                 *((UINT32 *)(&(Hd->Signature[0])))
                 );
             break;
         case SIGNATURE_TYPE_GUID:
-            CatPrint(Str, L"HD(Part%d,Sig%g)",
+            CatPrint(Str, L"HD(%d,GPT,%g)",
                 Hd->PartitionNumber,
                 (EFI_GUID *) &(Hd->Signature[0])
                 );
             break;
         default:
-            CatPrint(Str, L"HD(Part%d,MBRType=%02x,SigType=%02x)",
+            CatPrint(Str, L"HD(%d,%d,0)",
                 Hd->PartitionNumber,
-                Hd->MBRType,
                 Hd->SignatureType
                 );
             break;
